@@ -77,7 +77,7 @@ class Exceptions:
 
 class AmplifyBackendClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html)
     """
 
@@ -93,7 +93,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#can_paginate)
         """
 
@@ -103,7 +103,7 @@ class AmplifyBackendClient(BaseClient):
         """
         This operation clones an existing backend.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.clone_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#clone_backend)
         """
 
@@ -113,13 +113,13 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         AppName: str,
         BackendEnvironmentName: str,
-        ResourceConfig: Mapping[str, Any] = None,
-        ResourceName: str = None
+        ResourceConfig: Mapping[str, Any] = ...,
+        ResourceName: str = ...
     ) -> CreateBackendResponseTypeDef:
         """
         This operation creates a backend for an Amplify app.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend)
         """
 
@@ -134,7 +134,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Creates a new backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_api)
         """
 
@@ -149,17 +149,17 @@ class AmplifyBackendClient(BaseClient):
         """
         Creates a new backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_auth)
         """
 
     def create_backend_config(
-        self, *, AppId: str, BackendManagerAppId: str = None
+        self, *, AppId: str, BackendManagerAppId: str = ...
     ) -> CreateBackendConfigResponseTypeDef:
         """
         Creates a config object for a backend.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.create_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_backend_config)
         """
 
@@ -168,7 +168,7 @@ class AmplifyBackendClient(BaseClient):
         Generates a one-time challenge code to authenticate a user into your Amplify
         Admin UI.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.create_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#create_token)
         """
 
@@ -178,7 +178,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Removes an existing environment from your Amplify project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend)
         """
 
@@ -188,12 +188,12 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         BackendEnvironmentName: str,
         ResourceName: str,
-        ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
+        ResourceConfig: "BackendAPIResourceConfigTypeDef" = ...
     ) -> DeleteBackendAPIResponseTypeDef:
         """
         Deletes an existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend_api)
         """
 
@@ -203,7 +203,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Deletes an existing backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_backend_auth)
         """
 
@@ -211,7 +211,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Deletes the challenge token based on the given appId and sessionId.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.delete_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#delete_token)
         """
 
@@ -221,31 +221,31 @@ class AmplifyBackendClient(BaseClient):
         """
         Generates a model schema for an existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_backend_api_models)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#generate_backend_api_models)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#generate_presigned_url)
         """
 
     def get_backend(
-        self, *, AppId: str, BackendEnvironmentName: str = None
+        self, *, AppId: str, BackendEnvironmentName: str = ...
     ) -> GetBackendResponseTypeDef:
         """
         Provides project-level details for your Amplify UI project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend)
         """
 
@@ -255,12 +255,12 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         BackendEnvironmentName: str,
         ResourceName: str,
-        ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
+        ResourceConfig: "BackendAPIResourceConfigTypeDef" = ...
     ) -> GetBackendAPIResponseTypeDef:
         """
         Gets the details for a backend API.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_api)
         """
 
@@ -270,7 +270,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Generates a model schema for existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_api_models)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_api_models)
         """
 
@@ -280,7 +280,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Gets a backend auth details.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_auth)
         """
 
@@ -290,7 +290,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Returns information about a specific job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.get_backend_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_backend_job)
         """
 
@@ -298,7 +298,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Gets the challenge token based on the given appId and sessionId.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.get_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#get_token)
         """
 
@@ -310,12 +310,12 @@ class AmplifyBackendClient(BaseClient):
         NativeClientId: str,
         UserPoolId: str,
         WebClientId: str,
-        IdentityPoolId: str = None
+        IdentityPoolId: str = ...
     ) -> ImportBackendAuthResponseTypeDef:
         """
         Imports an existing backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.import_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.import_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#import_backend_auth)
         """
 
@@ -324,26 +324,26 @@ class AmplifyBackendClient(BaseClient):
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        JobId: str = None,
-        MaxResults: int = None,
-        NextToken: str = None,
-        Operation: str = None,
-        Status: str = None
+        JobId: str = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        Operation: str = ...,
+        Status: str = ...
     ) -> ListBackendJobsResponseTypeDef:
         """
         Lists the jobs for the backend of an Amplify app.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.list_backend_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#list_backend_jobs)
         """
 
     def remove_all_backends(
-        self, *, AppId: str, CleanAmplifyApp: bool = None
+        self, *, AppId: str, CleanAmplifyApp: bool = ...
     ) -> RemoveAllBackendsResponseTypeDef:
         """
         Removes all backend environments from your Amplify project.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_all_backends)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#remove_all_backends)
         """
 
@@ -351,7 +351,7 @@ class AmplifyBackendClient(BaseClient):
         """
         Removes the AWS resources required to access the Amplify Admin UI.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.remove_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#remove_backend_config)
         """
 
@@ -361,12 +361,12 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         BackendEnvironmentName: str,
         ResourceName: str,
-        ResourceConfig: "BackendAPIResourceConfigTypeDef" = None
+        ResourceConfig: "BackendAPIResourceConfigTypeDef" = ...
     ) -> UpdateBackendAPIResponseTypeDef:
         """
         Updates an existing backend API resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_api)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_api)
         """
 
@@ -381,17 +381,17 @@ class AmplifyBackendClient(BaseClient):
         """
         Updates an existing backend authentication resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_auth)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_auth)
         """
 
     def update_backend_config(
-        self, *, AppId: str, LoginAuthConfig: "LoginAuthConfigReqObjTypeDef" = None
+        self, *, AppId: str, LoginAuthConfig: "LoginAuthConfigReqObjTypeDef" = ...
     ) -> UpdateBackendConfigResponseTypeDef:
         """
         Updates the AWS resources required to access the Amplify Admin UI.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_config)
         """
 
@@ -401,13 +401,13 @@ class AmplifyBackendClient(BaseClient):
         AppId: str,
         BackendEnvironmentName: str,
         JobId: str,
-        Operation: str = None,
-        Status: str = None
+        Operation: str = ...,
+        Status: str = ...
     ) -> UpdateBackendJobResponseTypeDef:
         """
         Updates a specific job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Client.update_backend_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/client.html#update_backend_job)
         """
 
@@ -415,6 +415,6 @@ class AmplifyBackendClient(BaseClient):
         self, operation_name: Literal["list_backend_jobs"]
     ) -> ListBackendJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
         """
