@@ -40,7 +40,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListBackendJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
     """
 
@@ -49,12 +49,12 @@ class ListBackendJobsPaginator(Boto3Paginator):
         *,
         AppId: str,
         BackendEnvironmentName: str,
-        JobId: str = None,
-        Operation: str = None,
-        Status: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        JobId: str = ...,
+        Operation: str = ...,
+        Status: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListBackendJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.48/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.52/reference/services/amplifybackend.html#AmplifyBackend.Paginator.ListBackendJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amplifybackend/paginators.html#listbackendjobspaginator)
         """
